@@ -203,10 +203,10 @@ class NamedNodeSet:
     def Union(self,list1,list2,result):
         'joins two sets together, with the result having all the individual members'
         ans = []
-        if self.set.ContainsKey(list1):
+        if list1 in self.set.keys():
             for bon in self.set[list1]:
                 ans.Append(bon)
-        if self.set.ContainsKey(list2):
+        if list2 in self.set.keys():
             for bon in self.set[list2]:
                 if not bon in ans:
                     ans.Append(bon)
@@ -302,7 +302,7 @@ class OntologyTripleRefs:
             self.SetOntologyName("LocalOntology")
         self.curOntList.append(t)
     def SetOntologyName(self,name):
-        if self.set.ContainsKey(name):
+        if name in self.set.keys():
             self.curOntList = set[name]
         else:
             self.curOntList = []
@@ -1090,7 +1090,7 @@ class FuncOnt:
             predName=self.TrimStart(Pred)
             if len(predName)==0:
                 return -2
-            if results.set.ContainsKey(predName):
+            if predName in results.set.keys():
                 results.set.Remove(predName)
 
         if Sub[0] != '?':
@@ -1105,7 +1105,7 @@ class FuncOnt:
             subName = self.TrimStart(Sub)
             if len(subName) == 0:
                 return -1
-            if results.set.ContainsKey(subName):
+            if subName in results.set.keys():
                 results.set.Remove(subName)
 
         if Obj[0]!='?':
